@@ -1,10 +1,11 @@
 """Port `table` function from r-base"""
 import numpy as np
-import pandas as pd
-from pandas import DataFrame, Series
-from pandas.api.types import is_scalar, is_categorical_dtype
 from pipda import register_func
 
+from ..core.backends import pandas as pd
+from ..core.backends.pandas import DataFrame, Series
+from ..core.backends.pandas.api.types import is_scalar, is_categorical_dtype
+
 from ..core.contexts import Context
 from ..core.utils import ensure_nparray, regcall
 from ..core.defaults import NA_REPR
