@@ -1,37 +1,19 @@
 """Provide options"""
 
+from os import access, R_OK
 from typing import Any, Generator, Mapping, Union, Callable
 from contextlib import contextmanager
+from pathlib import Path
 
+import toml
 from diot import Diot
 from pipda import options as pipda_options
 
-
 _key_transform = lambda key: key.replace("_", ".")
 _dict_transform_back = lambda dic: {
     key.replace(".", "_"): val for key, val in dic.items()
 }
 
-OPTIONS = Diot(
-    # Whether use 0-based numbers when index is involved, acts similar like R
-    dplyr_summarise_inform=True,
-    # whether warn about importing functions that override builtin ones.
-    warn_builtin_names=True,
-    #
-    enable_pdtypes=False,
-    # add_option=True,
-    # allow 'a.b' to access 'a_b'
-    diot_transform=_key_transform,
-    # Warn about failure to get ast node
-    warn_astnode_failure=True,
-    # All piping mode:
-    # - Assume all verbs are using PIPING_VERB env
-    # - Assume all data functions are using PIPING env
-    # - Assume all non-data functions are using PIPING verbs
-    # This is useful when source code is not available.
-    assume_all_piping=False,
-)
-
 
 def enable_pdtypes_callback(enable: bool) -> None:  # pragma: no cover
     from .utils import logger
@@ -62,8 +44,57 @@ OPTION_CALLBACKS = Diot(
 )
 
 
+def _read_options(path: Path) -> dict:
+    """Read options from a file"""
+    if not path.is_file() or not access(path, R_OK):
+        return {}
+
+    with path.open("r") as fopt:
+        return toml.load(fopt)
+
+
+OPTION_FILE_HOME = Path("~/.datar.toml").expanduser()
+OPTION_FILE_CWD = Path("./.datar.toml").resolve()
+
+
+OPTIONS = Diot(
+    # Whether use 0-based numbers when index is involved, acts similar like R
+    dplyr_summarise_inform=True,
+    # What to do when there are conflicts importing names
+    # - `warn`: show warnings
+    # - `silent`: ignore the conflicts
+    # - `underscore_suffixed`: add suffix `_` to the conflicting names
+    #   (and don't do any warnings)
+    import_names_conflict="warn",
+    # Enable pdtypes
+    enable_pdtypes=True,
+    # add_option=True,
+    # allow 'a.b' to access 'a_b'
+    diot_transform=_key_transform,
+    # Warn about failure to get ast node
+    warn_astnode_failure=True,
+    # All piping mode:
+    # - Assume all verbs are using PIPING_VERB env
+    # - Assume all data functions are using PIPING env
+    # - Assume all non-data functions are using PIPING verbs
+    # This is useful when source code is not available.
+    assume_all_piping=False,
+    # The backend for datar
+    backend="pandas",  # or "modin"
+)
+OPTIONS.update(_read_options(OPTION_FILE_HOME))
+OPTIONS.update(_read_options(OPTION_FILE_CWD))
+
+
+def apply_init_callbacks():
+    """Apply the callbacks when options are initialized"""
+    for key in OPTION_CALLBACKS:
+        OPTION_CALLBACKS[key](OPTIONS[key])
+
+
 def options(
     *args: Union[str, Mapping[str, Any]],
+    _return: bool = None,
     **kwargs: Any,
 ) -> Mapping[str, Any]:
     """Allow the user to set and examine a variety of global options
@@ -71,8 +102,13 @@ def options(
     Args:
         *args: Names of options to return
         **kwargs: name-value pair to create/set an option
+        _return: Whether return the options.
+            If `None`, turned to `True` when option names provided in `args`.
+
+    Returns:
+        The options before updating if `_return` is `True`.
     """
-    if not args and not kwargs:
+    if not args and not kwargs and (_return is None or _return is True):
         return OPTIONS.copy()
 
     names = [arg.replace(".", "_") for arg in args if isinstance(arg, str)]
@@ -82,14 +118,19 @@ def options(
             pairs.update(_dict_transform_back(arg))
     pairs.update(_dict_transform_back(kwargs))
 
-    out = Diot(
-        {
-            name: value
-            for name, value in OPTIONS.items()
-            if name in names or name in pairs
-        },
-        diot_transform=_key_transform,
-    )
+    out = None
+    if _return is None:
+        _return = names
+
+    if _return:
+        out = Diot(
+            {
+                name: value
+                for name, value in OPTIONS.items()
+                if name in names or name in pairs
+            },
+            diot_transform=_key_transform,
+        )
 
     for key, val in pairs.items():
         oldval = OPTIONS[key]
