@@ -6,9 +6,10 @@ from typing import Iterable
 import operator
 
 import numpy as np
-from pandas import DataFrame, Series
 from pipda import register_verb
 
+from ..core.backends.pandas import DataFrame, Series
+
 from ..core.contexts import Context
 from ..core.utils import logger, regcall
 from ..core.tibble import Tibble, TibbleGrouped, reconstruct_tibble
