@@ -3,11 +3,12 @@
 https://github.com/tidyverse/dplyr/blob/master/R/rows.R
 """
 import numpy as np
-import pandas as pd
-from pandas import DataFrame
-from pandas.api.types import is_scalar
 from pipda import register_verb
 
+from ..core.backends import pandas as pd
+from ..core.backends.pandas import DataFrame
+from ..core.backends.pandas.api.types import is_scalar
+
 from ..base import setdiff
 from ..core.utils import logger, regcall
 from ..tibble import rownames_to_column
